aboutsummaryrefslogtreecommitdiff
path: root/src/include/utils/tzparser.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/utils/tzparser.h')
-rw-r--r--src/include/utils/tzparser.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/include/utils/tzparser.h b/src/include/utils/tzparser.h
index 82728a67dd0..637f449e36c 100644
--- a/src/include/utils/tzparser.h
+++ b/src/include/utils/tzparser.h
@@ -22,10 +22,12 @@
*/
typedef struct tzEntry
{
- /* the actual data: TZ abbrev (downcased), offset, DST flag */
- char *abbrev;
- int offset; /* in seconds from UTC */
- bool is_dst;
+ /* the actual data */
+ char *abbrev; /* TZ abbreviation (downcased) */
+ char *zone; /* zone name if dynamic abbrev, else NULL */
+ /* for a dynamic abbreviation, offset/is_dst are not used */
+ int offset; /* offset in seconds from UTC */
+ bool is_dst; /* true if a DST abbreviation */
/* source information (for error messages) */
int lineno;
const char *filename;